/*
 * Copyright (c) Huawei Technologies Co., Ltd. 2020-2020. All rights reserved.
 * Description: 通讯组件（CM）event异步调用 示例程序客户端源码文件
 */
#include "client_activity.h"
#include <string>
#include <thread>

namespace sample
{
    void ClientActivity::setupProxies()
    {
        for (uint8_t i = 0; i < ClientActivity::SENSORS_A_COUNT; i++)
        {
            proxySocA_[i] = nullptr;
        }


    }
    ClientActivity::ClientActivity() : validDataCount_(0U)
    {
        setupProxies();
    }

    ClientActivity::~ClientActivity()
    {
        Stop();
    }

    void ClientActivity::Init()
    {
        log_.LogInfo() << "Enter init";
        bool result = mdc::visual::Connect();
        if (result)
        {
            log_.LogInfo() << "The MViz server address is parsed and the visualization client is created successfully.";
        }
        else
        {
            log_.LogError() << "Failed to parse the MViz server address, or a visualization client has been created.";
            isInitialized = false;
            return;
        }
        isInitialized = true;
        // 客户端启动服务查找，注册服务发现回调。
        // 注意：StartFindService第2个参数为InstanceSpecifier类型。
        // 参数的值取配置文件network_binding.json中的instanceSpecifier属性的值。
        CameraA_setupFindService();

        HesaiLidarRight1_setupFindService();
        HesaiLidarRight2_setupFindService();
        HesaiLidarLeft1_setupFindService();
        HesaiLidarLeft2_setupFindService();
        InnoLidarFront1_setupFindService();
        InnoLidarFront2_setupFindService();

        
        CameraA_setupPublishers();


        // for (int i = 0; i < HESAI_COUNT; i++)
        // {
        //     /* code */
        // }

        HesaiLidarLeft1_setupPublishers();
        HesaiLidarLeft2_setupPublishers();
        HesaiLidarRight1_setupPublishers();
        HesaiLidarRight2_setupPublishers();
        InnoLidarFront1_setupPublishers();
        InnoLidarFront2_setupPublishers();



        InnoLidarFront1_initPointCloud2();
        InnoLidarFront1_runThread();

        InnoLidarFront2_initPointCloud2();
        InnoLidarFront2_runThread();


        log_.LogInfo() << "Finding Services..";
    }
    void ClientActivity::Stop()
    {
        CameraA_stop();

        HesaiLidarRight1_stop();
        HesaiLidarRight2_stop();
        HesaiLidarLeft1_stop();
        HesaiLidarLeft2_stop();
        InnoLidarFront1_stop();
        InnoLidarFront2_stop();
    }

} // namespace
